@@ -6,9 +6,9 @@ Type annotations for qldb service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_qldb.type_defs import CancelJournalKinesisStreamRequestTypeDef
+    from mypy_boto3_qldb.type_defs import CancelJournalKinesisStreamRequestRequestTypeDef
 
-    data: CancelJournalKinesisStreamRequestTypeDef = {...}
+    data: CancelJournalKinesisStreamRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -31,78 +31,78 @@ else:
 
 
 __all__ = (
-    "CancelJournalKinesisStreamRequestTypeDef",
-    "CancelJournalKinesisStreamResponseResponseTypeDef",
-    "CreateLedgerRequestTypeDef",
-    "CreateLedgerResponseResponseTypeDef",
-    "DeleteLedgerRequestTypeDef",
-    "DescribeJournalKinesisStreamRequestTypeDef",
-    "DescribeJournalKinesisStreamResponseResponseTypeDef",
-    "DescribeJournalS3ExportRequestTypeDef",
-    "DescribeJournalS3ExportResponseResponseTypeDef",
-    "DescribeLedgerRequestTypeDef",
-    "DescribeLedgerResponseResponseTypeDef",
-    "ExportJournalToS3RequestTypeDef",
-    "ExportJournalToS3ResponseResponseTypeDef",
-    "GetBlockRequestTypeDef",
-    "GetBlockResponseResponseTypeDef",
-    "GetDigestRequestTypeDef",
-    "GetDigestResponseResponseTypeDef",
-    "GetRevisionRequestTypeDef",
-    "GetRevisionResponseResponseTypeDef",
+    "CancelJournalKinesisStreamRequestRequestTypeDef",
+    "CancelJournalKinesisStreamResponseTypeDef",
+    "CreateLedgerRequestRequestTypeDef",
+    "CreateLedgerResponseTypeDef",
+    "DeleteLedgerRequestRequestTypeDef",
+    "DescribeJournalKinesisStreamRequestRequestTypeDef",
+    "DescribeJournalKinesisStreamResponseTypeDef",
+    "DescribeJournalS3ExportRequestRequestTypeDef",
+    "DescribeJournalS3ExportResponseTypeDef",
+    "DescribeLedgerRequestRequestTypeDef",
+    "DescribeLedgerResponseTypeDef",
+    "ExportJournalToS3RequestRequestTypeDef",
+    "ExportJournalToS3ResponseTypeDef",
+    "GetBlockRequestRequestTypeDef",
+    "GetBlockResponseTypeDef",
+    "GetDigestRequestRequestTypeDef",
+    "GetDigestResponseTypeDef",
+    "GetRevisionRequestRequestTypeDef",
+    "GetRevisionResponseTypeDef",
     "JournalKinesisStreamDescriptionTypeDef",
     "JournalS3ExportDescriptionTypeDef",
     "KinesisConfigurationTypeDef",
     "LedgerSummaryTypeDef",
-    "ListJournalKinesisStreamsForLedgerRequestTypeDef",
-    "ListJournalKinesisStreamsForLedgerResponseResponseTypeDef",
-    "ListJournalS3ExportsForLedgerRequestTypeDef",
-    "ListJournalS3ExportsForLedgerResponseResponseTypeDef",
-    "ListJournalS3ExportsRequestTypeDef",
-    "ListJournalS3ExportsResponseResponseTypeDef",
-    "ListLedgersRequestTypeDef",
-    "ListLedgersResponseResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "ListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
+    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
+    "ListJournalS3ExportsForLedgerRequestRequestTypeDef",
+    "ListJournalS3ExportsForLedgerResponseTypeDef",
+    "ListJournalS3ExportsRequestRequestTypeDef",
+    "ListJournalS3ExportsResponseTypeDef",
+    "ListLedgersRequestRequestTypeDef",
+    "ListLedgersResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "ResponseMetadataTypeDef",
     "S3EncryptionConfigurationTypeDef",
     "S3ExportConfigurationTypeDef",
-    "StreamJournalToKinesisRequestTypeDef",
-    "StreamJournalToKinesisResponseResponseTypeDef",
-    "TagResourceRequestTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateLedgerPermissionsModeRequestTypeDef",
-    "UpdateLedgerPermissionsModeResponseResponseTypeDef",
-    "UpdateLedgerRequestTypeDef",
-    "UpdateLedgerResponseResponseTypeDef",
+    "StreamJournalToKinesisRequestRequestTypeDef",
+    "StreamJournalToKinesisResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateLedgerPermissionsModeRequestRequestTypeDef",
+    "UpdateLedgerPermissionsModeResponseTypeDef",
+    "UpdateLedgerRequestRequestTypeDef",
+    "UpdateLedgerResponseTypeDef",
     "ValueHolderTypeDef",
 )
 
-CancelJournalKinesisStreamRequestTypeDef = TypedDict(
-    "CancelJournalKinesisStreamRequestTypeDef",
+CancelJournalKinesisStreamRequestRequestTypeDef = TypedDict(
+    "CancelJournalKinesisStreamRequestRequestTypeDef",
     {
         "LedgerName": str,
         "StreamId": str,
     },
 )
 
-CancelJournalKinesisStreamResponseResponseTypeDef = TypedDict(
-    "CancelJournalKinesisStreamResponseResponseTypeDef",
+CancelJournalKinesisStreamResponseTypeDef = TypedDict(
+    "CancelJournalKinesisStreamResponseTypeDef",
     {
         "StreamId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateLedgerRequestTypeDef = TypedDict(
-    "_RequiredCreateLedgerRequestTypeDef",
+_RequiredCreateLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLedgerRequestRequestTypeDef",
     {
         "Name": str,
         "PermissionsMode": PermissionsModeType,
     },
 )
-_OptionalCreateLedgerRequestTypeDef = TypedDict(
-    "_OptionalCreateLedgerRequestTypeDef",
+_OptionalCreateLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLedgerRequestRequestTypeDef",
     {
         "Tags": Dict[str, str],
         "DeletionProtection": bool,
@@ -111,14 +111,14 @@ _OptionalCreateLedgerRequestTypeDef = TypedDict(
 )
 
 
-class CreateLedgerRequestTypeDef(
-    _RequiredCreateLedgerRequestTypeDef, _OptionalCreateLedgerRequestTypeDef
+class CreateLedgerRequestRequestTypeDef(
+    _RequiredCreateLedgerRequestRequestTypeDef, _OptionalCreateLedgerRequestRequestTypeDef
 ):
     pass
 
 
-CreateLedgerResponseResponseTypeDef = TypedDict(
-    "CreateLedgerResponseResponseTypeDef",
+CreateLedgerResponseTypeDef = TypedDict(
+    "CreateLedgerResponseTypeDef",
     {
         "Name": str,
         "Arn": str,
@@ -130,54 +130,54 @@ CreateLedgerResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteLedgerRequestTypeDef = TypedDict(
-    "DeleteLedgerRequestTypeDef",
+DeleteLedgerRequestRequestTypeDef = TypedDict(
+    "DeleteLedgerRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-DescribeJournalKinesisStreamRequestTypeDef = TypedDict(
-    "DescribeJournalKinesisStreamRequestTypeDef",
+DescribeJournalKinesisStreamRequestRequestTypeDef = TypedDict(
+    "DescribeJournalKinesisStreamRequestRequestTypeDef",
     {
         "LedgerName": str,
         "StreamId": str,
     },
 )
 
-DescribeJournalKinesisStreamResponseResponseTypeDef = TypedDict(
-    "DescribeJournalKinesisStreamResponseResponseTypeDef",
+DescribeJournalKinesisStreamResponseTypeDef = TypedDict(
+    "DescribeJournalKinesisStreamResponseTypeDef",
     {
         "Stream": "JournalKinesisStreamDescriptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeJournalS3ExportRequestTypeDef = TypedDict(
-    "DescribeJournalS3ExportRequestTypeDef",
+DescribeJournalS3ExportRequestRequestTypeDef = TypedDict(
+    "DescribeJournalS3ExportRequestRequestTypeDef",
     {
         "Name": str,
         "ExportId": str,
     },
 )
 
-DescribeJournalS3ExportResponseResponseTypeDef = TypedDict(
-    "DescribeJournalS3ExportResponseResponseTypeDef",
+DescribeJournalS3ExportResponseTypeDef = TypedDict(
+    "DescribeJournalS3ExportResponseTypeDef",
     {
         "ExportDescription": "JournalS3ExportDescriptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeLedgerRequestTypeDef = TypedDict(
-    "DescribeLedgerRequestTypeDef",
+DescribeLedgerRequestRequestTypeDef = TypedDict(
+    "DescribeLedgerRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-DescribeLedgerResponseResponseTypeDef = TypedDict(
-    "DescribeLedgerResponseResponseTypeDef",
+DescribeLedgerResponseTypeDef = TypedDict(
+    "DescribeLedgerResponseTypeDef",
     {
         "Name": str,
         "Arn": str,
@@ -189,8 +189,8 @@ DescribeLedgerResponseResponseTypeDef = TypedDict(
     },
 )
 
-ExportJournalToS3RequestTypeDef = TypedDict(
-    "ExportJournalToS3RequestTypeDef",
+ExportJournalToS3RequestRequestTypeDef = TypedDict(
+    "ExportJournalToS3RequestRequestTypeDef",
     {
         "Name": str,
         "InclusiveStartTime": Union[datetime, str],
@@ -200,23 +200,23 @@ ExportJournalToS3RequestTypeDef = TypedDict(
     },
 )
 
-ExportJournalToS3ResponseResponseTypeDef = TypedDict(
-    "ExportJournalToS3ResponseResponseTypeDef",
+ExportJournalToS3ResponseTypeDef = TypedDict(
+    "ExportJournalToS3ResponseTypeDef",
     {
         "ExportId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredGetBlockRequestTypeDef = TypedDict(
-    "_RequiredGetBlockRequestTypeDef",
+_RequiredGetBlockRequestRequestTypeDef = TypedDict(
+    "_RequiredGetBlockRequestRequestTypeDef",
     {
         "Name": str,
         "BlockAddress": "ValueHolderTypeDef",
     },
 )
-_OptionalGetBlockRequestTypeDef = TypedDict(
-    "_OptionalGetBlockRequestTypeDef",
+_OptionalGetBlockRequestRequestTypeDef = TypedDict(
+    "_OptionalGetBlockRequestRequestTypeDef",
     {
         "DigestTipAddress": "ValueHolderTypeDef",
     },
@@ -224,12 +224,14 @@ _OptionalGetBlockRequestTypeDef = TypedDict(
 )
 
 
-class GetBlockRequestTypeDef(_RequiredGetBlockRequestTypeDef, _OptionalGetBlockRequestTypeDef):
+class GetBlockRequestRequestTypeDef(
+    _RequiredGetBlockRequestRequestTypeDef, _OptionalGetBlockRequestRequestTypeDef
+):
     pass
 
 
-GetBlockResponseResponseTypeDef = TypedDict(
-    "GetBlockResponseResponseTypeDef",
+GetBlockResponseTypeDef = TypedDict(
+    "GetBlockResponseTypeDef",
     {
         "Block": "ValueHolderTypeDef",
         "Proof": "ValueHolderTypeDef",
@@ -237,15 +239,15 @@ GetBlockResponseResponseTypeDef = TypedDict(
     },
 )
 
-GetDigestRequestTypeDef = TypedDict(
-    "GetDigestRequestTypeDef",
+GetDigestRequestRequestTypeDef = TypedDict(
+    "GetDigestRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-GetDigestResponseResponseTypeDef = TypedDict(
-    "GetDigestResponseResponseTypeDef",
+GetDigestResponseTypeDef = TypedDict(
+    "GetDigestResponseTypeDef",
     {
         "Digest": bytes,
         "DigestTipAddress": "ValueHolderTypeDef",
@@ -253,16 +255,16 @@ GetDigestResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetRevisionRequestTypeDef = TypedDict(
-    "_RequiredGetRevisionRequestTypeDef",
+_RequiredGetRevisionRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRevisionRequestRequestTypeDef",
     {
         "Name": str,
         "BlockAddress": "ValueHolderTypeDef",
         "DocumentId": str,
     },
 )
-_OptionalGetRevisionRequestTypeDef = TypedDict(
-    "_OptionalGetRevisionRequestTypeDef",
+_OptionalGetRevisionRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRevisionRequestRequestTypeDef",
     {
         "DigestTipAddress": "ValueHolderTypeDef",
     },
@@ -270,14 +272,14 @@ _OptionalGetRevisionRequestTypeDef = TypedDict(
 )
 
 
-class GetRevisionRequestTypeDef(
-    _RequiredGetRevisionRequestTypeDef, _OptionalGetRevisionRequestTypeDef
+class GetRevisionRequestRequestTypeDef(
+    _RequiredGetRevisionRequestRequestTypeDef, _OptionalGetRevisionRequestRequestTypeDef
 ):
     pass
 
 
-GetRevisionResponseResponseTypeDef = TypedDict(
-    "GetRevisionResponseResponseTypeDef",
+GetRevisionResponseTypeDef = TypedDict(
+    "GetRevisionResponseTypeDef",
     {
         "Proof": "ValueHolderTypeDef",
         "Revision": "ValueHolderTypeDef",
@@ -360,14 +362,14 @@ LedgerSummaryTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListJournalKinesisStreamsForLedgerRequestTypeDef = TypedDict(
-    "_RequiredListJournalKinesisStreamsForLedgerRequestTypeDef",
+_RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
     {
         "LedgerName": str,
     },
 )
-_OptionalListJournalKinesisStreamsForLedgerRequestTypeDef = TypedDict(
-    "_OptionalListJournalKinesisStreamsForLedgerRequestTypeDef",
+_OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -376,15 +378,15 @@ _OptionalListJournalKinesisStreamsForLedgerRequestTypeDef = TypedDict(
 )
 
 
-class ListJournalKinesisStreamsForLedgerRequestTypeDef(
-    _RequiredListJournalKinesisStreamsForLedgerRequestTypeDef,
-    _OptionalListJournalKinesisStreamsForLedgerRequestTypeDef,
+class ListJournalKinesisStreamsForLedgerRequestRequestTypeDef(
+    _RequiredListJournalKinesisStreamsForLedgerRequestRequestTypeDef,
+    _OptionalListJournalKinesisStreamsForLedgerRequestRequestTypeDef,
 ):
     pass
 
 
-ListJournalKinesisStreamsForLedgerResponseResponseTypeDef = TypedDict(
-    "ListJournalKinesisStreamsForLedgerResponseResponseTypeDef",
+ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
+    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
     {
         "Streams": List["JournalKinesisStreamDescriptionTypeDef"],
         "NextToken": str,
@@ -392,14 +394,14 @@ ListJournalKinesisStreamsForLedgerResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListJournalS3ExportsForLedgerRequestTypeDef = TypedDict(
-    "_RequiredListJournalS3ExportsForLedgerRequestTypeDef",
+_RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
-_OptionalListJournalS3ExportsForLedgerRequestTypeDef = TypedDict(
-    "_OptionalListJournalS3ExportsForLedgerRequestTypeDef",
+_OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -408,15 +410,15 @@ _OptionalListJournalS3ExportsForLedgerRequestTypeDef = TypedDict(
 )
 
 
-class ListJournalS3ExportsForLedgerRequestTypeDef(
-    _RequiredListJournalS3ExportsForLedgerRequestTypeDef,
-    _OptionalListJournalS3ExportsForLedgerRequestTypeDef,
+class ListJournalS3ExportsForLedgerRequestRequestTypeDef(
+    _RequiredListJournalS3ExportsForLedgerRequestRequestTypeDef,
+    _OptionalListJournalS3ExportsForLedgerRequestRequestTypeDef,
 ):
     pass
 
 
-ListJournalS3ExportsForLedgerResponseResponseTypeDef = TypedDict(
-    "ListJournalS3ExportsForLedgerResponseResponseTypeDef",
+ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
+    "ListJournalS3ExportsForLedgerResponseTypeDef",
     {
         "JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"],
         "NextToken": str,
@@ -424,8 +426,8 @@ ListJournalS3ExportsForLedgerResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListJournalS3ExportsRequestTypeDef = TypedDict(
-    "ListJournalS3ExportsRequestTypeDef",
+ListJournalS3ExportsRequestRequestTypeDef = TypedDict(
+    "ListJournalS3ExportsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -433,8 +435,8 @@ ListJournalS3ExportsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListJournalS3ExportsResponseResponseTypeDef = TypedDict(
-    "ListJournalS3ExportsResponseResponseTypeDef",
+ListJournalS3ExportsResponseTypeDef = TypedDict(
+    "ListJournalS3ExportsResponseTypeDef",
     {
         "JournalS3Exports": List["JournalS3ExportDescriptionTypeDef"],
         "NextToken": str,
@@ -442,8 +444,8 @@ ListJournalS3ExportsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListLedgersRequestTypeDef = TypedDict(
-    "ListLedgersRequestTypeDef",
+ListLedgersRequestRequestTypeDef = TypedDict(
+    "ListLedgersRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -451,8 +453,8 @@ ListLedgersRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListLedgersResponseResponseTypeDef = TypedDict(
-    "ListLedgersResponseResponseTypeDef",
+ListLedgersResponseTypeDef = TypedDict(
+    "ListLedgersResponseTypeDef",
     {
         "Ledgers": List["LedgerSummaryTypeDef"],
         "NextToken": str,
@@ -460,15 +462,15 @@ ListLedgersResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -516,8 +518,8 @@ S3ExportConfigurationTypeDef = TypedDict(
     },
 )
 
-_RequiredStreamJournalToKinesisRequestTypeDef = TypedDict(
-    "_RequiredStreamJournalToKinesisRequestTypeDef",
+_RequiredStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
+    "_RequiredStreamJournalToKinesisRequestRequestTypeDef",
     {
         "LedgerName": str,
         "RoleArn": str,
@@ -526,8 +528,8 @@ _RequiredStreamJournalToKinesisRequestTypeDef = TypedDict(
         "StreamName": str,
     },
 )
-_OptionalStreamJournalToKinesisRequestTypeDef = TypedDict(
-    "_OptionalStreamJournalToKinesisRequestTypeDef",
+_OptionalStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
+    "_OptionalStreamJournalToKinesisRequestRequestTypeDef",
     {
         "Tags": Dict[str, str],
         "ExclusiveEndTime": Union[datetime, str],
@@ -536,46 +538,47 @@ _OptionalStreamJournalToKinesisRequestTypeDef = TypedDict(
 )
 
 
-class StreamJournalToKinesisRequestTypeDef(
-    _RequiredStreamJournalToKinesisRequestTypeDef, _OptionalStreamJournalToKinesisRequestTypeDef
+class StreamJournalToKinesisRequestRequestTypeDef(
+    _RequiredStreamJournalToKinesisRequestRequestTypeDef,
+    _OptionalStreamJournalToKinesisRequestRequestTypeDef,
 ):
     pass
 
 
-StreamJournalToKinesisResponseResponseTypeDef = TypedDict(
-    "StreamJournalToKinesisResponseResponseTypeDef",
+StreamJournalToKinesisResponseTypeDef = TypedDict(
+    "StreamJournalToKinesisResponseTypeDef",
     {
         "StreamId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "Tags": Dict[str, str],
     },
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
         "TagKeys": List[str],
     },
 )
 
-UpdateLedgerPermissionsModeRequestTypeDef = TypedDict(
-    "UpdateLedgerPermissionsModeRequestTypeDef",
+UpdateLedgerPermissionsModeRequestRequestTypeDef = TypedDict(
+    "UpdateLedgerPermissionsModeRequestRequestTypeDef",
     {
         "Name": str,
         "PermissionsMode": PermissionsModeType,
     },
 )
 
-UpdateLedgerPermissionsModeResponseResponseTypeDef = TypedDict(
-    "UpdateLedgerPermissionsModeResponseResponseTypeDef",
+UpdateLedgerPermissionsModeResponseTypeDef = TypedDict(
+    "UpdateLedgerPermissionsModeResponseTypeDef",
     {
         "Name": str,
         "Arn": str,
@@ -584,14 +587,14 @@ UpdateLedgerPermissionsModeResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateLedgerRequestTypeDef = TypedDict(
-    "_RequiredUpdateLedgerRequestTypeDef",
+_RequiredUpdateLedgerRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLedgerRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
-_OptionalUpdateLedgerRequestTypeDef = TypedDict(
-    "_OptionalUpdateLedgerRequestTypeDef",
+_OptionalUpdateLedgerRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLedgerRequestRequestTypeDef",
     {
         "DeletionProtection": bool,
     },
@@ -599,14 +602,14 @@ _OptionalUpdateLedgerRequestTypeDef = TypedDict(
 )
 
 
-class UpdateLedgerRequestTypeDef(
-    _RequiredUpdateLedgerRequestTypeDef, _OptionalUpdateLedgerRequestTypeDef
+class UpdateLedgerRequestRequestTypeDef(
+    _RequiredUpdateLedgerRequestRequestTypeDef, _OptionalUpdateLedgerRequestRequestTypeDef
 ):
     pass
 
 
-UpdateLedgerResponseResponseTypeDef = TypedDict(
-    "UpdateLedgerResponseResponseTypeDef",
+UpdateLedgerResponseTypeDef = TypedDict(
+    "UpdateLedgerResponseTypeDef",
     {
         "Name": str,
         "Arn": str,
